<a id="mypy-boto3-codecommit"></a>

# mypy-boto3-codecommit

[![PyPI - mypy-boto3-codecommit](https://img.shields.io/pypi/v/mypy-boto3-codecommit.svg?color=blue)](https://pypi.org/project/mypy-boto3-codecommit)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-codecommit.svg?color=blue)](https://pypi.org/project/mypy-boto3-codecommit)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-codecommit?color=blue)](https://pypistats.org/packages/mypy-boto3-codecommit)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.CodeCommit 1.17.111](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codecommit.html#CodeCommit)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.22.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-codecommit docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codecommit/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-codecommit](#mypy-boto3-codecommit)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `CodeCommit` service.

```bash
python -m pip install boto3-stubs[codecommit]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[codecommit]` in your environment:
  `python -m pip install 'boto3-stubs[codecommit]'`

Both type checking and auto-complete should work for `CodeCommit` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[codecommit]` in your environment:
  `python -m pip install 'boto3-stubs[codecommit]'`

Both type checking and auto-complete should work for `CodeCommit` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[codecommit]` in your environment:
  `python -m pip install 'boto3-stubs[codecommit]'`
- Run `mypy` as usual

Type checking should work for `CodeCommit` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[codecommit]` in your environment:
  `python -m pip install 'boto3-stubs[codecommit]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `CodeCommit` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`CodeCommitClient` provides annotations for `boto3.client("codecommit")`.

```python
import boto3

from mypy_boto3_codecommit import CodeCommitClient

client: CodeCommitClient = boto3.client("codecommit")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: CodeCommitClient = session.client("codecommit")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_codecommit.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_codecommit import CodeCommitClient
from mypy_boto3_codecommit.paginator import (
    DescribePullRequestEventsPaginator,
    GetCommentsForComparedCommitPaginator,
    GetCommentsForPullRequestPaginator,
    GetDifferencesPaginator,
    ListBranchesPaginator,
    ListPullRequestsPaginator,
    ListRepositoriesPaginator,
)

client: CodeCommitClient = boto3.client("codecommit")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_pull_request_events_paginator: DescribePullRequestEventsPaginator = client.get_paginator("describe_pull_request_events")
get_comments_for_compared_commit_paginator: GetCommentsForComparedCommitPaginator = client.get_paginator("get_comments_for_compared_commit")
get_comments_for_pull_request_paginator: GetCommentsForPullRequestPaginator = client.get_paginator("get_comments_for_pull_request")
get_differences_paginator: GetDifferencesPaginator = client.get_paginator("get_differences")
list_branches_paginator: ListBranchesPaginator = client.get_paginator("list_branches")
list_pull_requests_paginator: ListPullRequestsPaginator = client.get_paginator("list_pull_requests")
list_repositories_paginator: ListRepositoriesPaginator = client.get_paginator("list_repositories")
```

<a id="literals"></a>

### Literals

`mypy_boto3_codecommit.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_codecommit.literals import (
    ApprovalStateType,
    ChangeTypeEnumType,
    ConflictDetailLevelTypeEnumType,
    ConflictResolutionStrategyTypeEnumType,
    DescribePullRequestEventsPaginatorName,
    FileModeTypeEnumType,
    GetCommentsForComparedCommitPaginatorName,
    GetCommentsForPullRequestPaginatorName,
    GetDifferencesPaginatorName,
    ListBranchesPaginatorName,
    ListPullRequestsPaginatorName,
    ListRepositoriesPaginatorName,
    MergeOptionTypeEnumType,
    ObjectTypeEnumType,
    OrderEnumType,
    OverrideStatusType,
    PullRequestEventTypeType,
    PullRequestStatusEnumType,
    RelativeFileVersionEnumType,
    ReplacementTypeEnumType,
    RepositoryTriggerEventEnumType,
    SortByEnumType,
)

def check_value(value: ApprovalStateType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_codecommit.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_codecommit.type_defs import (
    ApprovalRuleEventMetadataTypeDef,
    ApprovalRuleOverriddenEventMetadataTypeDef,
    ApprovalRuleTemplateTypeDef,
    ApprovalRuleTypeDef,
    ApprovalStateChangedEventMetadataTypeDef,
    ApprovalTypeDef,
    AssociateApprovalRuleTemplateWithRepositoryInputRequestTypeDef,
    BatchAssociateApprovalRuleTemplateWithRepositoriesErrorTypeDef,
    BatchAssociateApprovalRuleTemplateWithRepositoriesInputRequestTypeDef,
    BatchAssociateApprovalRuleTemplateWithRepositoriesOutputTypeDef,
    BatchDescribeMergeConflictsErrorTypeDef,
    BatchDescribeMergeConflictsInputRequestTypeDef,
    BatchDescribeMergeConflictsOutputTypeDef,
    BatchDisassociateApprovalRuleTemplateFromRepositoriesErrorTypeDef,
    BatchDisassociateApprovalRuleTemplateFromRepositoriesInputRequestTypeDef,
    BatchDisassociateApprovalRuleTemplateFromRepositoriesOutputTypeDef,
    BatchGetCommitsErrorTypeDef,
    BatchGetCommitsInputRequestTypeDef,
    BatchGetCommitsOutputTypeDef,
    BatchGetRepositoriesInputRequestTypeDef,
    BatchGetRepositoriesOutputTypeDef,
    BlobMetadataTypeDef,
    BranchInfoTypeDef,
    CommentTypeDef,
    CommentsForComparedCommitTypeDef,
    CommentsForPullRequestTypeDef,
    CommitTypeDef,
    ConflictMetadataTypeDef,
    ConflictResolutionTypeDef,
    ConflictTypeDef,
    CreateApprovalRuleTemplateInputRequestTypeDef,
    CreateApprovalRuleTemplateOutputTypeDef,
    CreateBranchInputRequestTypeDef,
    CreateCommitInputRequestTypeDef,
    CreateCommitOutputTypeDef,
    CreatePullRequestApprovalRuleInputRequestTypeDef,
    CreatePullRequestApprovalRuleOutputTypeDef,
    CreatePullRequestInputRequestTypeDef,
    CreatePullRequestOutputTypeDef,
    CreateRepositoryInputRequestTypeDef,
    CreateRepositoryOutputTypeDef,
    CreateUnreferencedMergeCommitInputRequestTypeDef,
    CreateUnreferencedMergeCommitOutputTypeDef,
    DeleteApprovalRuleTemplateInputRequestTypeDef,
    DeleteApprovalRuleTemplateOutputTypeDef,
    DeleteBranchInputRequestTypeDef,
    DeleteBranchOutputTypeDef,
    DeleteCommentContentInputRequestTypeDef,
    DeleteCommentContentOutputTypeDef,
    DeleteFileEntryTypeDef,
    DeleteFileInputRequestTypeDef,
    DeleteFileOutputTypeDef,
    DeletePullRequestApprovalRuleInputRequestTypeDef,
    DeletePullRequestApprovalRuleOutputTypeDef,
    DeleteRepositoryInputRequestTypeDef,
    DeleteRepositoryOutputTypeDef,
    DescribeMergeConflictsInputRequestTypeDef,
    DescribeMergeConflictsOutputTypeDef,
    DescribePullRequestEventsInputRequestTypeDef,
    DescribePullRequestEventsOutputTypeDef,
    DifferenceTypeDef,
    DisassociateApprovalRuleTemplateFromRepositoryInputRequestTypeDef,
    EvaluatePullRequestApprovalRulesInputRequestTypeDef,
    EvaluatePullRequestApprovalRulesOutputTypeDef,
    EvaluationTypeDef,
    FileMetadataTypeDef,
    FileModesTypeDef,
    FileSizesTypeDef,
    FileTypeDef,
    FolderTypeDef,
    GetApprovalRuleTemplateInputRequestTypeDef,
    GetApprovalRuleTemplateOutputTypeDef,
    GetBlobInputRequestTypeDef,
    GetBlobOutputTypeDef,
    GetBranchInputRequestTypeDef,
    GetBranchOutputTypeDef,
    GetCommentInputRequestTypeDef,
    GetCommentOutputTypeDef,
    GetCommentReactionsInputRequestTypeDef,
    GetCommentReactionsOutputTypeDef,
    GetCommentsForComparedCommitInputRequestTypeDef,
    GetCommentsForComparedCommitOutputTypeDef,
    GetCommentsForPullRequestInputRequestTypeDef,
    GetCommentsForPullRequestOutputTypeDef,
    GetCommitInputRequestTypeDef,
    GetCommitOutputTypeDef,
    GetDifferencesInputRequestTypeDef,
    GetDifferencesOutputTypeDef,
    GetFileInputRequestTypeDef,
    GetFileOutputTypeDef,
    GetFolderInputRequestTypeDef,
    GetFolderOutputTypeDef,
    GetMergeCommitInputRequestTypeDef,
    GetMergeCommitOutputTypeDef,
    GetMergeConflictsInputRequestTypeDef,
    GetMergeConflictsOutputTypeDef,
    GetMergeOptionsInputRequestTypeDef,
    GetMergeOptionsOutputTypeDef,
    GetPullRequestApprovalStatesInputRequestTypeDef,
    GetPullRequestApprovalStatesOutputTypeDef,
    GetPullRequestInputRequestTypeDef,
    GetPullRequestOutputTypeDef,
    GetPullRequestOverrideStateInputRequestTypeDef,
    GetPullRequestOverrideStateOutputTypeDef,
    GetRepositoryInputRequestTypeDef,
    GetRepositoryOutputTypeDef,
    GetRepositoryTriggersInputRequestTypeDef,
    GetRepositoryTriggersOutputTypeDef,
    IsBinaryFileTypeDef,
    ListApprovalRuleTemplatesInputRequestTypeDef,
    ListApprovalRuleTemplatesOutputTypeDef,
    ListAssociatedApprovalRuleTemplatesForRepositoryInputRequestTypeDef,
    ListAssociatedApprovalRuleTemplatesForRepositoryOutputTypeDef,
    ListBranchesInputRequestTypeDef,
    ListBranchesOutputTypeDef,
    ListPullRequestsInputRequestTypeDef,
    ListPullRequestsOutputTypeDef,
    ListRepositoriesForApprovalRuleTemplateInputRequestTypeDef,
    ListRepositoriesForApprovalRuleTemplateOutputTypeDef,
    ListRepositoriesInputRequestTypeDef,
    ListRepositoriesOutputTypeDef,
    ListTagsForResourceInputRequestTypeDef,
    ListTagsForResourceOutputTypeDef,
    LocationTypeDef,
    MergeBranchesByFastForwardInputRequestTypeDef,
    MergeBranchesByFastForwardOutputTypeDef,
    MergeBranchesBySquashInputRequestTypeDef,
    MergeBranchesBySquashOutputTypeDef,
    MergeBranchesByThreeWayInputRequestTypeDef,
    MergeBranchesByThreeWayOutputTypeDef,
    MergeHunkDetailTypeDef,
    MergeHunkTypeDef,
    MergeMetadataTypeDef,
    MergeOperationsTypeDef,
    MergePullRequestByFastForwardInputRequestTypeDef,
    MergePullRequestByFastForwardOutputTypeDef,
    MergePullRequestBySquashInputRequestTypeDef,
    MergePullRequestBySquashOutputTypeDef,
    MergePullRequestByThreeWayInputRequestTypeDef,
    MergePullRequestByThreeWayOutputTypeDef,
    ObjectTypesTypeDef,
    OriginApprovalRuleTemplateTypeDef,
    OverridePullRequestApprovalRulesInputRequestTypeDef,
    PaginatorConfigTypeDef,
    PostCommentForComparedCommitInputRequestTypeDef,
    PostCommentForComparedCommitOutputTypeDef,
    PostCommentForPullRequestInputRequestTypeDef,
    PostCommentForPullRequestOutputTypeDef,
    PostCommentReplyInputRequestTypeDef,
    PostCommentReplyOutputTypeDef,
    PullRequestCreatedEventMetadataTypeDef,
    PullRequestEventTypeDef,
    PullRequestMergedStateChangedEventMetadataTypeDef,
    PullRequestSourceReferenceUpdatedEventMetadataTypeDef,
    PullRequestStatusChangedEventMetadataTypeDef,
    PullRequestTargetTypeDef,
    PullRequestTypeDef,
    PutCommentReactionInputRequestTypeDef,
    PutFileEntryTypeDef,
    PutFileInputRequestTypeDef,
    PutFileOutputTypeDef,
    PutRepositoryTriggersInputRequestTypeDef,
    PutRepositoryTriggersOutputTypeDef,
    ReactionForCommentTypeDef,
    ReactionValueFormatsTypeDef,
    ReplaceContentEntryTypeDef,
    RepositoryMetadataTypeDef,
    RepositoryNameIdPairTypeDef,
    RepositoryTriggerExecutionFailureTypeDef,
    RepositoryTriggerTypeDef,
    ResponseMetadataTypeDef,
    SetFileModeEntryTypeDef,
    SourceFileSpecifierTypeDef,
    SubModuleTypeDef,
    SymbolicLinkTypeDef,
    TagResourceInputRequestTypeDef,
    TargetTypeDef,
    TestRepositoryTriggersInputRequestTypeDef,
    TestRepositoryTriggersOutputTypeDef,
    UntagResourceInputRequestTypeDef,
    UpdateApprovalRuleTemplateContentInputRequestTypeDef,
    UpdateApprovalRuleTemplateContentOutputTypeDef,
    UpdateApprovalRuleTemplateDescriptionInputRequestTypeDef,
    UpdateApprovalRuleTemplateDescriptionOutputTypeDef,
    UpdateApprovalRuleTemplateNameInputRequestTypeDef,
    UpdateApprovalRuleTemplateNameOutputTypeDef,
    UpdateCommentInputRequestTypeDef,
    UpdateCommentOutputTypeDef,
    UpdateDefaultBranchInputRequestTypeDef,
    UpdatePullRequestApprovalRuleContentInputRequestTypeDef,
    UpdatePullRequestApprovalRuleContentOutputTypeDef,
    UpdatePullRequestApprovalStateInputRequestTypeDef,
    UpdatePullRequestDescriptionInputRequestTypeDef,
    UpdatePullRequestDescriptionOutputTypeDef,
    UpdatePullRequestStatusInputRequestTypeDef,
    UpdatePullRequestStatusOutputTypeDef,
    UpdatePullRequestTitleInputRequestTypeDef,
    UpdatePullRequestTitleOutputTypeDef,
    UpdateRepositoryDescriptionInputRequestTypeDef,
    UpdateRepositoryNameInputRequestTypeDef,
    UserInfoTypeDef,
)

def get_structure() -> ApprovalRuleEventMetadataTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-codecommit` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-codecommit docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codecommit/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
